@@ -1,7 +1,7 @@
 #' @importFrom magrittr %>%
-#' @title Current Probability of Failure for 30-60kV cables
+#' @title Current Probability of Failure for 33-66kV cables
 #' @description This function calculates the current
-#' annual probability of failure per kilometer for a 30-60kV cables.
+#' annual probability of failure per kilometer for a 33-66kV cables.
 #' The function is a cubic curve that is based on
 #' the first three terms of the Taylor series for an
 #' exponential function. For more information about the
@@ -11,11 +11,11 @@
 #' A sting that refers to the specific asset category.
 #' See See page 17, table 1 in CNAIM (2021).
 #' Options:
-#' \code{cable_type = c("30kV UG Cable (Gas)", "60kV UG Cable (Gas)",
-#' "30kV UG Cable (Non Pressurised)", "60kV UG Cable (Non Pressurised)",
-#' "30kV UG Cable (Oil)", "60kV UG Cable (Oil)")
+#' \code{cable_type = c("33kV UG Cable (Gas)", "66kV UG Cable (Gas)",
+#' "33kV UG Cable (Non Pressurised)", "66kV UG Cable (Non Pressurised)",
+#' "33kV UG Cable (Oil)", "66kV UG Cable (Oil)")
 #'}. The default setting is
-#' \code{cable_type = "60kV UG Cable (Gas)"}.
+#' \code{cable_type = "66kV UG Cable (Gas)"}.
 #' @param sub_division String. Refers to material the sheath and conductor is
 #' made of. Options:
 #' \code{sub_division = c("Aluminium sheath - Aluminium conductor",
@@ -42,27 +42,27 @@
 #' See page 157, table 182 (oil) and 183 (gas) in CNAIM (2021).
 #' @inheritParams current_health
 #' @param age  Numeric. The current age in years of the cable.
-#' @return Numeric. Current probability of failure
-#' per annum per kilometre for 60/30kV cables.
+#' @return DataFrame Current probability of failure
+#' per annum per kilometer along with current health score.
 #' @source DNO Common Network Asset Indices Methodology (CNAIM),
 #' Health & Criticality - Version 2.1, 2021:
 #' \url{https://www.ofgem.gov.uk/sites/default/files/docs/2021/04/dno_common_network_asset_indices_methodology_v2.1_final_01-04-2021.pdf}
 #' @export
 #' @examples
 #' # Current annual probability of failure for
-#' # "60kV UG Cable (Non Pressurised)", 50 years old
-#'pof_cables_60_30kv(cable_type = "66kV UG Cable (Non Pressurised)",
-#'sub_division = "Lead sheath - Copper conductor",
-#'utilisation_pct = 80,
-#'operating_voltage_pct = 60,
-#'sheath_test = "Default",
-#'partial_discharge = "Default",
-#'fault_hist = "Default",
-#'leakage = "Default",
-#'reliability_factor = "Default",
-#'age = 50) * 100
-pof_cables_60_30kv <-
-  function(cable_type = "60kV UG Cable (Gas)",
+#' # "66kV UG Cable (Non Pressurised)", 50 years old
+#' pof_cables_66_33kv(cable_type = "66kV UG Cable (Non Pressurised)",
+#' sub_division = "Lead sheath - Copper conductor",
+#' utilisation_pct = 80,
+#' operating_voltage_pct = 60,
+#' sheath_test = "Default",
+#' partial_discharge = "Default",
+#' fault_hist = "Default",
+#' leakage = "Default",
+#' reliability_factor = "Default",
+#' age = 50)
+pof_cables_66_33kv <-
+  function(cable_type = "66kV UG Cable (Gas)",
            sub_division = "Aluminium sheath - Aluminium conductor",
            utilisation_pct = "Default",
            operating_voltage_pct = "Default",
@@ -73,22 +73,6 @@ pof_cables_60_30kv <-
            reliability_factor = "Default",
            age) {
 
-    if (cable_type == "30kV UG Cable (Non Pressurised)" ) {
-      cable_type <- "33kV UG Cable (Non Pressurised)"
-    } else if ( cable_type == "30kV UG Cable (Oil)") {
-      cable_type <- "33kV UG Cable (Oil)"
-    } else if ( cable_type == "30kV UG Cable (Gas)") {
-      cable_type <- "33kV UG Cable (Gas)"
-    } else if ( cable_type == "60kV UG Cable (Non Pressurised)") {
-      cable_type <- "66kV UG Cable (Non Pressurised)"
-    } else if ( cable_type == "60kV UG Cable (Oil)") {
-      cable_type <- "66kV UG Cable (Oil)"
-    } else {
-      cable_type <- "66kV UG Cable (Gas)"
-    }
-
-
-
     `Asset Register Category` = `Health Index Asset Category` =
       `Generic Term...1` = `Generic Term...2` = `Functional Failure Category` =
       `K-Value (%)` = `C-Value` = `Asset Register  Category` =
@@ -371,5 +355,5 @@ pof_cables_60_30kv <-
          (((c * current_health_score)^3) / factorial(3)))
 
 
-    return(probability_of_failure)
+    return(data.frame(pof = probability_of_failure, chs = current_health_score))
   }
